#!/usr/bin/env node
// Copyright IBM Corp. 2016. All Rights Reserved.
// Node module: apiconnect-cli-catalogs
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.

/********************************************************* {COPYRIGHT-TOP} ***
 * IBM Confidential
 * OCO Source Materials
 * 5725-C11, 5725-C12, 7198-8FX, 5725-F70, 5725-F71, 5725-F72, 5725-L30
 *
 * (C) Copyright IBM Corporation 2015  All Rights Reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 ********************************************************* {COPYRIGHT-END} **/

var ApicCliUtil = require('apiconnect-cli-util');
var ApimCatalogsListFormatter = require('./formatter/catalogs_list_formatter');
var Promise = require('bluebird');
var f = require('util').format;

var host = ApicCliUtil.Util.host;
var providerOrgName = ApicCliUtil.Util.providerOrgName;
var Catalogs = ApicCliUtil.Catalogs;
var context = ApicCliUtil.Context;

module.exports.catalogsList = function(options) {
  var program = {};
  var fmt = new ApimCatalogsListFormatter();

  program.organization = options.organization;
  program.allOrganizations = options.allOrganizations;
  program.server = options.server || host();

  if (!program.server) {
    throw new Error(f('Server is required.'));
  }
  if (program.organization && program.allOrganizations) {
    throw new Error(f('Should specify only one of --organization ORGANIZATION | --all-organizations'));
  }
  if (!program.organization && !program.allOrganizations) {
    var setOrg = providerOrgName();
    if (!setOrg) {
      throw new Error(f('--organization ORGANIZATION | --all-organizations is required'));
    }
    program.organization = setOrg;
  }

  if (options.server) {
    context.set({ server: options.server });
  }
  if (options.organization) {
    context.set({ organization: options.organization });
  }

  var orgOptions = {
    allOrganizations: program.allOrganizations,
    organization: program.organization,
    allCatalogs: true,
  };
  var catalogs = new Catalogs();

  context.set(orgOptions);
  var list = Promise.promisify(catalogs.list);

  return list.call(catalogs)
    .then(function(res) {
      var response = catalogs.filter(orgOptions);
      fmt.format(response, orgOptions);
    })
    .catch(function(err) {
      fmt.error(err);
    });
};
